# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .zendesk_credential import ZendeskCredential
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class TicketingZendesk(UncheckedBaseModel):
    """
    Configuration for Zendesk as a Ticketing Provider
    """

    credential: ZendeskCredential
    url: str = pydantic.Field()
    """
    Base URL for your Zendesk tenant.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
