# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import datetime as dt
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class OperationSchedule(UncheckedBaseModel):
    run_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Run now or on the specified time.
    """

    interval: typing.Optional[str] = pydantic.Field(default=None)
    """
    Set the interval duration for recuring operations. (minimum 1h)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
