# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .create_asset_status import CreateAssetStatus
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class CreateAssetDevice(UncheckedBaseModel):
    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the device.
    """

    status: CreateAssetStatus = pydantic.Field()
    """
    Status of the creation of the asset in the providers system.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
