# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from ...common.types.id import Id
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class Usage(UncheckedBaseModel):
    integration_id: Id
    requests_count: float
    cpu_time_seconds: float
    db_operations_count: float
    int_ops_count: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
