# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing
from ...capabilities_base.types.category_id import CategoryId
import typing

if typing.TYPE_CHECKING:
    from .connector import Connector
ConnectorOrId = typing.Union[CategoryId, "Connector"]
