# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .tanium_cloud_credential import TaniumCloudCredential
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class AssetsTaniumCloud(UncheckedBaseModel):
    """
    Configuration for Tanium Cloud as an Assets Provider

    [Configuration guide](https://docs.synqly.com/guides/provider-configuration/tanium-setup)
    """

    credential: TaniumCloudCredential
    url: str = pydantic.Field()
    """
    Base URL for the Tanium Cloud API
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
