# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class UploadScanStatus(str, enum.Enum):
    UNKNOWN = "Unknown"
    PENDING = "Pending"
    COMPLETE = "Complete"
    ERROR = "Error"
    _UNKNOWN = "__UPLOADSCANSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "UploadScanStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        unknown: typing.Callable[[], T_Result],
        pending: typing.Callable[[], T_Result],
        complete: typing.Callable[[], T_Result],
        error: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is UploadScanStatus.UNKNOWN:
            return unknown()
        if self is UploadScanStatus.PENDING:
            return pending()
        if self is UploadScanStatus.COMPLETE:
            return complete()
        if self is UploadScanStatus.ERROR:
            return error()
        return _unknown_member(self._value_)
