# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ApplyMappingRequest(UncheckedBaseModel):
    mappings: typing.List[str] = pydantic.Field()
    """
    List of mappings to utilize. This can include custom mappings you have defined as well as Synqly built-in mappings.
    """

    data: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    JSON input data to apply the mapping chain to.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
